==> jc-1.4.0.tar.gz: soot/jimple/spark/sets/PointsToSetInternal__246.h <==
// class soot.jimple.spark.sets.PointsToSetInternal$6

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ac9a90c2da2d45e7 soot_jimple_spark_sets_P2SetVisitor
// @dep_class da5fe4881b14d067 soot_jimple_spark_sets_PointsToSetInternal__246

// header file dependencies
// @dep_header soot_jimple_spark_sets_P2SetVisitor

#include "soot/jimple/spark/sets/P2SetVisitor.h"

#ifndef _JC_soot_jimple_spark_sets_PointsToSetInternal__246_H_
#define _JC_soot_jimple_spark_sets_PointsToSetInternal__246_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashSet$object;
struct _jc_soot_jimple_spark_pag_Node$object;
struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$sub_refs	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$sub_refs;
typedef struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$sub_nonrefs	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$refs	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$refs;
typedef struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$nonrefs	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$nonrefs;
typedef struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$object	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$object;

typedef const struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$vmethods	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$vmethods;
typedef const struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$vtable	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$vtable;
typedef const struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$vtype	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$vtype;

// Constructors
extern void _jc_soot_jimple_spark_sets_PointsToSetInternal__246$method$_init$54f0c5777db53ceb(_jc_env *, struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$object *, struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object *, struct _jc_java_util_HashSet$object *);

// Virtual methods
extern void _jc_soot_jimple_spark_sets_PointsToSetInternal__246$method$visit$29be8db3232dadd5(_jc_env *, struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$object *, struct _jc_soot_jimple_spark_pag_Node$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_sets_PointsToSetInternal__246$method_info$visit$29be8db3232dadd5;

// Virtual methods structure
struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$vmethods {
	void	(*visit$29be8db3232dadd5)(_jc_env *, struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$object *, struct _jc_soot_jimple_spark_pag_Node$object *);
};

// Vtable
struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_sets_P2SetVisitor$vmethods	soot_jimple_spark_sets_P2SetVisitor;
	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$vmethods	soot_jimple_spark_sets_PointsToSetInternal__246;
};

// Vtype
struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$sub_refs {
	struct _jc_java_util_HashSet$object	*val__24ret;
	struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$refs {
    _jc_soot_jimple_spark_sets_PointsToSetInternal__246$sub_refs	soot_jimple_spark_sets_PointsToSetInternal__246;
    _jc_soot_jimple_spark_sets_P2SetVisitor$sub_refs	soot_jimple_spark_sets_P2SetVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_sets_P2SetVisitor$sub_nonrefs	soot_jimple_spark_sets_P2SetVisitor;
    _jc_soot_jimple_spark_sets_PointsToSetInternal__246$sub_nonrefs	soot_jimple_spark_sets_PointsToSetInternal__246;
};

// Object instance structure
struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$object {
	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$vtype	*vtype;
	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_sets_PointsToSetInternal__246$vtype _jc_soot_jimple_spark_sets_PointsToSetInternal__246$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_sets_PointsToSetInternal__246, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_sets_PointsToSetInternal__246$class_object;

#endif	/* _JC_soot_jimple_spark_sets_PointsToSetInternal__246_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/sets/PointsToSetInternal__246.h <==
// class soot.jimple.spark.sets.PointsToSetInternal$6

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ac9a90c2da2d45e7 soot_jimple_spark_sets_P2SetVisitor
// @dep_class da5fe4881b14d067 soot_jimple_spark_sets_PointsToSetInternal__246

// header file dependencies
// @dep_header soot_jimple_spark_sets_P2SetVisitor

#include "soot/jimple/spark/sets/P2SetVisitor.h"

#ifndef _JC_soot_jimple_spark_sets_PointsToSetInternal__246_H_
#define _JC_soot_jimple_spark_sets_PointsToSetInternal__246_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashSet$object;
struct _jc_soot_jimple_spark_pag_Node$object;
struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$sub_refs	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$sub_refs;
typedef struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$sub_nonrefs	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$refs	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$refs;
typedef struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$nonrefs	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$nonrefs;
typedef struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$object	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$object;

typedef const struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$vmethods	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$vmethods;
typedef const struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$vtable	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$vtable;
typedef const struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$vtype	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$vtype;

// Constructors
extern void _jc_soot_jimple_spark_sets_PointsToSetInternal__246$method$_init$54f0c5777db53ceb(_jc_env *, struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$object *, struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object *, struct _jc_java_util_HashSet$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_spark_sets_PointsToSetInternal__246$method$visit$29be8db3232dadd5(_jc_env *, struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$object *, struct _jc_soot_jimple_spark_pag_Node$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_sets_PointsToSetInternal__246$method_info$visit$29be8db3232dadd5;

// Virtual methods structure
struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$vmethods {
	void	(*visit$29be8db3232dadd5)(_jc_env *, struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$object *, struct _jc_soot_jimple_spark_pag_Node$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_sets_P2SetVisitor$vmethods	soot_jimple_spark_sets_P2SetVisitor;
	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$vmethods	soot_jimple_spark_sets_PointsToSetInternal__246;
};

// Vtype
struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$sub_refs {
	struct _jc_java_util_HashSet$object	*val__24ret;
	struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$refs {
    _jc_soot_jimple_spark_sets_PointsToSetInternal__246$sub_refs	soot_jimple_spark_sets_PointsToSetInternal__246;
    _jc_soot_jimple_spark_sets_P2SetVisitor$sub_refs	soot_jimple_spark_sets_P2SetVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_sets_P2SetVisitor$sub_nonrefs	soot_jimple_spark_sets_P2SetVisitor;
    _jc_soot_jimple_spark_sets_PointsToSetInternal__246$sub_nonrefs	soot_jimple_spark_sets_PointsToSetInternal__246;
};

// Object instance structure
struct _jc_soot_jimple_spark_sets_PointsToSetInternal__246$object {
	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$vtype	*vtype;
	_jc_soot_jimple_spark_sets_PointsToSetInternal__246$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_sets_PointsToSetInternal__246$vtype _jc_soot_jimple_spark_sets_PointsToSetInternal__246$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_sets_PointsToSetInternal__246, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_sets_PointsToSetInternal__246$class_object;

#endif	/* _JC_soot_jimple_spark_sets_PointsToSetInternal__246_H_ */
